aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--phpBB/phpbb/avatar/manager.php13
1 files changed, 10 insertions, 3 deletions
diff --git a/phpBB/phpbb/avatar/manager.php b/phpBB/phpbb/avatar/manager.php
index 90cd83898f..9f6a5fb089 100644
--- a/phpBB/phpbb/avatar/manager.php
+++ b/phpBB/phpbb/avatar/manager.php
@@ -183,8 +183,9 @@ class manager
* @param array $row User data or group data
* @param string $prefix Prefix of data keys (e.g. user), should not include the trailing underscore
*
* @return array User data or group data with keys that have been
* stripped from the preceding "user_" or "group_"
*/
static public function clean_row($row, $prefix = '')
{
@@ -198,8 +199,14 @@ class manager
$values = array_values($row);
array_walk($keys, array('\phpbb\avatar\manager', 'strip_prefix'), $prefix);
+ $row = array_combine($keys, $values);
- return array_combine($keys, $values);
+ if ($prefix == 'group')
+ {
+ $row['id'] = 'g' . $row['id'];
+ }
+
+ return $row;
}
/**
@@ -183,8 +183,9 @@ class manager
* @param string $prefix Prefix of data keys (e.g. user), should not include the trailing underscore
*
- * @return array User data or group data with keys that have been
- * stripped from the preceding "user_" or "group_"
+ * @return array User or group data with keys that have been
+ * stripped from the preceding "user_" or "group_"
+ * Also the group id is prefixed with g, when the prefix group is removed.
*/
static public function clean_row($row, $prefix = '')